@@ -63,7 +63,7 @@ from typing_extensions import Literal, get_args
 ################################
 logger = logging.getLogger(__name__)
 T = TypeVar("T")
-VERSION = "1.0.17"
+VERSION = "1.0.20"
 
 
 ####################
@@ -328,6 +328,8 @@ class SegmentsClient:
         enable_interpolation: bool = True,
         enable_same_dimensions_track_constraint: bool = False,
         enable_save_button: bool = False,
+        enable_label_status_verified: bool = False,
+        enable_3d_cuboid_rotation: bool = False,
         organization: Optional[str] = None,
     ) -> Dataset:
         """Add a dataset.
@@ -376,6 +378,8 @@ class SegmentsClient:
             enable_interpolation: Enable label interpolation in sequence datasets. Ignored for non-sequence datasets. Defaults to :obj:`True`.
             enable_same_dimensions_track_constraint: Enable constraint to keep same cuboid dimensions for the entire object track in point cloud cuboid datasets. Ignored for non-cuboid datasets. Defaults to :obj:`False`.
             enable_save_button: Enable a save button in the labeling and reviewing workflow, to save unfinished work. Defaults to :obj:`False`.
+            enable_label_status_verified: Enable an additional label status "Verified". Defaults to :obj:`False`.
+            enable_3d_cuboid_rotation: Enable 3D cuboid rotation (i.e., yaw, pitch and roll). Defaults to :obj:`False`.
             organization: The username of the organization for which this dataset should be created. None will create a dataset for the current user. Defaults to :obj:`None`.
         Raises:
             :exc:`~segments.exceptions.ValidationError`: If validation of the task attributes fails.
@@ -417,6 +421,8 @@ class SegmentsClient:
             "enable_interpolation": enable_interpolation,
             "enable_same_dimensions_track_constraint": enable_same_dimensions_track_constraint,
             "enable_save_button": enable_save_button,
+            "enable_label_status_verified": enable_label_status_verified,
+            "enable_3d_cuboid_rotation": enable_3d_cuboid_rotation,
             "data_type": "IMAGE",
         }
 
@@ -445,6 +451,8 @@ class SegmentsClient:
         enable_interpolation: Optional[bool] = None,
         enable_same_dimensions_track_constraint: Optional[bool] = None,
         enable_save_button: Optional[bool] = None,
+        enable_label_status_verified: Optional[bool] = None,
+        enable_3d_cuboid_rotation: Optional[bool] = None,
     ) -> Dataset:
         """Update a dataset.
 
@@ -469,6 +477,8 @@ class SegmentsClient:
             enable_interpolation: Enable label interpolation in sequence datasets. Ignored for non-sequence datasets. Defaults to :obj:`None`.
             enable_same_dimensions_track_constraint: Enable constraint to keep same cuboid dimensions for the entire object track in point cloud cuboid datasets. Ignored for non-cuboid datasets. Defaults to :obj:`None`.
             enable_save_button: Enable a save button in the labeling and reviewing workflow, to save unfinished work. Defaults to :obj:`False`.
+            enable_label_status_verified: Enable an additional label status "Verified". Defaults to :obj:`False`.
+            enable_3d_cuboid_rotation: Enable 3D cuboid rotation (i.e., yaw, pitch and roll). Defaults to :obj:`False`.
         Raises:
             :exc:`~segments.exceptions.ValidationError`: If validation of the dataset fails.
             :exc:`~segments.exceptions.APILimitError`: If the API limit is exceeded.
@@ -521,6 +531,12 @@ class SegmentsClient:
         if enable_save_button:
             payload["enable_save_button"] = enable_save_button
 
+        if enable_label_status_verified:
+            payload["enable_label_status_verified"] = enable_label_status_verified
+
+        if enable_3d_cuboid_rotation:
+            payload["enable_3d_cuboid_rotation"] = enable_3d_cuboid_rotation
+
         r = self._patch(f"/datasets/{dataset_identifier}/", data=payload, model=Dataset)
         # logger.info(f"Updated {dataset_identifier}")
 
@@ -1363,6 +1379,29 @@ class SegmentsClient:
     ##########
     # Issues #
     ##########
+    def get_issues(self, dataset_identifier: str) -> List[Issue]:
+        """Get all issues for a dataset.
+
+        .. code-block:: python
+
+            dataset_identifier = 'jane/flowers'
+            issues = client.get_issues(dataset_identifier)
+            for issue in issues:
+                print(issue.uuid, issue.description, issue.status, issue.sample_uuid)
+
+        Args:
+            dataset_identifier: The dataset identifier, consisting of the name of the dataset owner followed by the name of the dataset itself. Example: ``jane/flowers``.
+        Raises:
+            :exc:`~segments.exceptions.APILimitError`: If the API limit is exceeded.
+            :exc:`~segments.exceptions.NotFoundError`: If the dataset is not found.
+            :exc:`~segments.exceptions.NetworkError`: If the request is not valid or if the server experienced an error.
+            :exc:`~segments.exceptions.TimeoutError`: If the request times out.
+        """
+
+        r = self._get(f"/datasets/{dataset_identifier}/issues/", model=List[Issue])
+
+        return cast(List[Issue], r)
+
     def add_issue(
         self,
         sample_uuid: str,
