@@ -30,6 +30,7 @@ LabelStatus = Literal[
     "PRELABELED",
     "SKIPPED",
     "UNLABELED",
+    "VERIFIED",
 ]
 TaskType = Literal[
     "segmentation-bitmap",
@@ -210,6 +211,13 @@ class XYZ(BaseModel):
     z: float
 
 
+class XYZW(BaseModel):
+    qx: float
+    qy: float
+    qz: float
+    qw: float
+
+
 # Point cloud cuboid
 # https://stackoverflow.com/questions/51575931/class-inheritance-in-python-3-7-dataclasses
 class PointcloudCuboidAnnotation(BaseModel):
@@ -218,6 +226,7 @@ class PointcloudCuboidAnnotation(BaseModel):
     position: XYZ
     dimensions: XYZ
     yaw: float
+    rotation: Optional[XYZW]
     type: Literal["cuboid", "cuboid-sync"]
     attributes: Optional[ObjectAttributes]
 
@@ -359,14 +368,7 @@ class ImageSequenceSampleAttributes(BaseModel):
 # Point cloud
 class PCD(BaseModel):
     url: str
-    type: Literal["pcd", "kitti", "nuscenes"] = "pcd"
-
-
-class XYZW(BaseModel):
-    qx: float
-    qy: float
-    qz: float
-    qw: float
+    type: Literal["pcd", "kitti", "nuscenes"]
 
 
 class EgoPose(BaseModel):
@@ -554,6 +556,7 @@ class Dataset(BaseModel):
     enable_skip_labeling: bool
     enable_skip_reviewing: bool
     enable_save_button: bool
+    enable_label_status_verified: bool
     enable_same_dimensions_track_constraint: bool
     enable_interpolation: bool
     task_type: TaskType
