@@ -3,6 +3,7 @@ from __future__ import annotations
 import copy
 import json
 import logging
+import os
 import random
 import re
 from collections import defaultdict
@@ -134,6 +135,48 @@ def export_dataset(
     | Polygon          | ``segmentation-bitmap`` and ``segmentation-bitmap-highres``                                        |
     +------------------+----------------------------------------------------------------------------------------------------+
 
+    Example:
+
+    .. code-block:: python
+
+        # pip install segments-ai
+        from segments import SegmentsClient, SegmentsDataset
+        from segments.utils import export_dataset
+
+        # Initialize a SegmentsDataset from the release file
+        client = SegmentsClient('YOUR_API_KEY')
+        release = client.get_release('jane/flowers', 'v1.0') # Alternatively: release = 'flowers-v1.0.json'
+        dataset = SegmentsDataset(release, labelset='ground-truth', filter_by=['labeled', 'reviewed'])
+
+        # Export to COCO panoptic format
+        export_dataset(dataset, export_format='coco-panoptic')
+
+
+    Alternatively, you can use the initialized :class:`.SegmentsDataset` to loop through the samples and labels, and visualize or process them in any way you please:
+
+    .. code-block:: python
+
+        import matplotlib.pyplot as plt
+        from segments.utils import get_semantic_bitmap
+
+        for sample in dataset:
+            # Print the sample name and list of labeled objects
+            print(sample['name'])
+            print(sample['annotations'])
+
+            # Show the image
+            plt.imshow(sample['image'])
+            plt.show()
+
+            # Show the instance segmentation label
+            plt.imshow(sample['segmentation_bitmap'])
+            plt.show()
+
+            # Show the semantic segmentation label
+            semantic_bitmap = get_semantic_bitmap(sample['segmentation_bitmap'], sample['annotations'])
+            plt.imshow(semantic_bitmap)
+            plt.show()
+
     Args:
         dataset: A :class:`.SegmentsDataset`.
         export_folder: The folder to export the dataset to. Defaults to ``.``.
@@ -274,7 +317,6 @@ def load_label_bitmap_from_url(
     def extract_bitmap(
         bitmap: Image.Image,
     ) -> npt.NDArray[np.uint32]:
-
         bitmap_array = np.array(bitmap)
         bitmap_array[:, :, 3] = 0
         bitmap_array = bitmap_array.view(np.uint32).squeeze(2)
@@ -332,7 +374,11 @@ def handle_exif_rotation(image: Image.Image) -> Image.Image:
 
 
 def show_polygons(
-    image_directory_path: str, image_id: int, exported_polygons_path: str, seed: int = 0
+    image_directory_path: str,
+    image_id: int,
+    exported_polygons_path: str,
+    seed: int = 0,
+    output_path: Optional[str] = None,
 ) -> None:
     """Show the exported contours of a segmented image (i.e., resulting from :func:`.export_dataset` with polygon export format).
 
@@ -341,6 +387,7 @@ def show_polygons(
         image_id: The image id (this can be found in the exported polygons JSON file).
         exported_polygons_path: The exported polygons path.
         seed: The seed used to generate random colors. Defaults to ``0``.
+        output_path: The directory to save the plot to. Defaults to :obj:`None`.
     Raises:
         :exc:`ImportError`: If matplotlib is not installed.
     """
@@ -409,7 +456,7 @@ def show_polygons(
     ) in category_name_polygons_with_annotations.items():
         for p in polygons:
             polygon = Polygon(
-                xy=np.asarray(p),
+                xy=np.asarray(p).reshape(-1, 2),
                 facecolor=color,
                 edgecolor=color,
                 label=category_name
@@ -453,4 +500,10 @@ def show_polygons(
 
     fig.legend()
 
+    if output_path:
+        path = os.path.join(
+            output_path, f"exported_polygons_from_image_id_{image_id:04d}"
+        )
+        plt.savefig(path, bbox_inches="tight")
+
     plt.show()
